==> sdcc_3.1.0+dfsg.orig.tar.gz: sdcc-3.1.0+dfsg/device/lib/_atoi.c <==
/*---------------------------------------------------------------------
   atoi - convert a string to an integer and return it

   Copyright (C) 1999, Sandeep Dutta . sandeep.dutta@usa.net

   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2.1, or (at your option) any
   later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License 
   along with this library; see the file COPYING. If not, write to the
   Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,
   MA 02110-1301, USA.

   As a special exception, if you link this library with other files,
   some of which are compiled with SDCC, to produce an executable,
   this library does not by itself cause the resulting executable to
   be covered by the GNU General Public License. This exception does
   not however invalidate any other reasons why the executable file
   might be covered by the GNU General Public License.
-------------------------------------------------------------------------*/

int atoi(const char * s)
{
    register int rv=0; 
    register char sign = 0;

    /* skip till we find either a digit or '+' or '-' */
    while (*s) {
        if (*s <= '9' && *s >= '0')
            break;
        if (*s == '-' || *s == '+') 
            break;
        s++;
    }    

    sign = (*s == '-');
    if (*s == '-' || *s == '+') s++;

    while (*s && *s >= '0' && *s <= '9') {
        rv = (rv * 10) + (*s - '0');
        s++;
    }

    return (sign ? -rv : rv);
}

==> sdcc_3.3.0+dfsg.orig.tar.gz: sdcc-3.3.0+dfsg/device/lib/_atoi.c <==
/*---------------------------------------------------------------------
   atoi - convert a string to an integer and return it

   Copyright (C) 1999, Sandeep Dutta . sandeep.dutta@usa.net

   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any
   later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License 
   along with this library; see the file COPYING. If not, write to the
   Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,
   MA 02110-1301, USA.

   As a special exception, if you link this library with other files,
   some of which are compiled with SDCC, to produce an executable,
   this library does not by itself cause the resulting executable to
   be covered by the GNU General Public License. This exception does
   not however invalidate any other reasons why the executable file
   might be covered by the GNU General Public License.
-------------------------------------------------------------------------*/

int atoi(const char * s)
{
    register int rv=0; 
    register char sign = 0;

    /* skip till we find either a digit or '+' or '-' */
    while (*s) {
        if (*s <= '9' && *s >= '0')
            break;
        if (*s == '-' || *s == '+') 
            break;
        s++;
    }    

    sign = (*s == '-');
    if (*s == '-' || *s == '+') s++;

    while (*s && *s >= '0' && *s <= '9') {
        rv = (rv * 10) + (*s - '0');
        s++;
    }

    return (sign ? -rv : rv);
}
